aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/extension
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/extension')
-rw-r--r--phpBB/phpbb/extension/manager.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/phpBB/phpbb/extension/manager.php b/phpBB/phpbb/extension/manager.php
index 00aa2c6826..4b4109bd85 100644
--- a/phpBB/phpbb/extension/manager.php
+++ b/phpBB/phpbb/extension/manager.php
@@ -262,8 +262,8 @@ class manager
*/
public function disable_step($name)
{
- // ignore extensions that are already disabled
- if ($this->is_disabled($name))
+ // ignore extensions that are not enabled
+ if (!$this->is_enabled($name))
{
return false;
}